# Glossary

```{glossary}
ACF
    Autocorrelation function.
    A measure of the correlation of a signal with itself at different time lags.

LAMMPS
    Large-scale atomic/molecular massively parallel simulator.
    A software package for simulating molecular dynamics.
    See https://www.lammps.org/

MD
    Molecular dynamics.
    A computational method used to simulate the physical movements of atoms and molecules.

NpT
    Isothermal-isobaric ensemble.
    A statistical ensemble that represents a system in thermal equilibrium
    with a heat bath at constant temperature (T), pressure (p), and number of particles (N).

NVE
    Microcanonical ensemble.
    A statistical ensemble that represents a closed system
    with fixed energy (E), volume (V), and number of particles (N).

NVT
    Canonical ensemble.
    A statistical ensemble that represents a system in thermal equilibrium
    with a heat bath at constant temperature (T), volume (V), and number of particles (N).

Uncertainty
    An estimate of the standard deviation of a result
    if the analysis would have been repeated many times with independent inputs.
    This is also known as the standard error.

PSD
    Power spectral density.
    A measure of the power of a signal as a function of frequency.
    The Fourier transform of the autocorrelation function.
```
